@@ -8,9 +8,8 @@ from types import TypeType
 from functools import wraps, partial
 from inspect import getmembers, ismethod, getargspec
 from copy import copy
-from byteplay import Code, LOAD_DEREF, LOAD_GLOBAL
 
-__version__ = '0.2'
+__version__ = '0.2.1'
 
 _stubbed_callables = []
 _modified_objects = []
@@ -264,6 +263,8 @@ def stub_unbound_function(target, repl):
 
 	fcode = copy(repl.func_code)
 
+	from byteplay import Code, LOAD_GLOBAL, LOAD_DEREF
+
 	co = Code.from_code(fcode)
 	co.filename = fcode.co_filename
 	co.firstlineno = fcode.co_firstlineno
@@ -430,6 +431,8 @@ def unstub_all():
 
 def same_args(f_tocopy):
 	def decorator(f_target):
+		from byteplay import Code
+
 		co = Code.from_code(f_target.func_code)
 		co.args, co.varargs, co.varkwargs, defaults = getargspec(f_tocopy)
 
